@@ -48,6 +48,7 @@ import javax.xml.stream.events.XMLEvent;
 import javax.xml.transform.Result;
 import javax.xml.transform.Source;
 import javax.xml.transform.dom.DOMSource;
+import javax.xml.transform.sax.SAXSource;
 
 import org.w3c.dom.Attr;
 import org.w3c.dom.CDATASection;
@@ -60,6 +61,9 @@ import org.w3c.dom.Node;
 import org.w3c.dom.ProcessingInstruction;
 import org.w3c.dom.Text;
 
+import org.xml.sax.InputSource;
+import org.xml.sax.XMLReader;
+
 import org.apache.cxf.common.logging.LogUtils;
 import org.apache.cxf.common.util.StringUtils;
 import org.apache.cxf.helpers.DOMUtils;
@@ -76,8 +80,16 @@ public final class StaxUtils {
     private static final String XML_NS = "http://www.w3.org/2000/xmlns/";
     
     static {
-        XML_INPUT_FACTORY.setProperty(XMLInputFactory.IS_NAMESPACE_AWARE, false);
-        XML_NS_AWARE_INPUT_FACTORY.setProperty(XMLInputFactory.IS_NAMESPACE_AWARE, true);
+        try {
+            XML_INPUT_FACTORY.setProperty(XMLInputFactory.IS_NAMESPACE_AWARE, false);
+        } catch (Exception e) {
+            //ignore
+        }
+        try {
+            XML_NS_AWARE_INPUT_FACTORY.setProperty(XMLInputFactory.IS_NAMESPACE_AWARE, true);
+        } catch (Exception ex) {
+            //ignore
+        }
     }
     
     private StaxUtils() {
@@ -279,6 +291,30 @@ public final class StaxUtils {
         }
         return false;
     }
+    public static void copy(Source source, XMLStreamWriter writer) throws XMLStreamException {
+        if (source instanceof SAXSource) {
+            InputSource src = ((SAXSource)source).getInputSource();
+            if (src.getByteStream() == null && src.getCharacterStream() == null
+                && src.getSystemId() == null && src.getPublicId() == null
+                && ((SAXSource)source).getXMLReader() != null) {
+                //OK - reader is OK.  We'll dump that out
+                StreamWriterContentHandler ch = new StreamWriterContentHandler(writer);
+                XMLReader reader = ((SAXSource)source).getXMLReader();
+                reader.setContentHandler(ch);
+                try {
+                    reader.parse(((SAXSource)source).getInputSource());
+                    return;
+                } catch (Exception e) {
+                    e.printStackTrace();
+                    throw new XMLStreamException(e);
+                }
+            }
+        }
+        
+        XMLStreamReader reader = createXMLStreamReader(source);
+        copy(reader, writer);
+        reader.close();
+    }
 
     public static Document copy(Document doc) 
         throws XMLStreamException, ParserConfigurationException {
@@ -684,7 +720,7 @@ public final class StaxUtils {
     private static boolean isDeclared(Element e, String namespaceURI, String prefix) {
         Attr att;
         if (prefix != null && prefix.length() > 0) {
-            att = e.getAttributeNodeNS(XML_NS, "xmlns:" + prefix);
+            att = e.getAttributeNodeNS(XML_NS, prefix);
         } else {
             att = e.getAttributeNode("xmlns");
         }
