@@ -27,7 +27,6 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.Executor;
-import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 import java.util.concurrent.FutureTask;
 import java.util.logging.Level;
@@ -81,6 +80,7 @@ import org.apache.cxf.phase.PhaseInterceptorChain;
 import org.apache.cxf.phase.PhaseManager;
 import org.apache.cxf.service.model.EndpointInfo;
 import org.apache.cxf.transport.MessageObserver;
+import org.apache.cxf.workqueue.WorkQueueManager;
 
 public class DispatchImpl<T> extends BindingProviderImpl implements Dispatch<T>, MessageObserver {
     private static final Logger LOG = LogUtils.getL7dLogger(DispatchImpl.class);
@@ -88,7 +88,6 @@ public class DispatchImpl<T> extends BindingProviderImpl implements Dispatch<T>,
 
     private Bus bus;
     private InterceptorProvider iProvider;
-
     private Class<T> cl;
     private Executor executor;
     private JAXBContext context;
@@ -344,10 +343,7 @@ public class DispatchImpl<T> extends BindingProviderImpl implements Dispatch<T>,
 
     private Executor getExecutor() {
         if (executor == null) {
-            executor = getEndpoint().getService().getExecutor();
-        }
-        if (executor == null) {
-            executor = Executors.newFixedThreadPool(5);
+            executor = bus.getExtension(WorkQueueManager.class).getAutomaticWorkQueue();
         }
         if (executor == null) {
             System.err.println("Can't not get executor");
@@ -360,6 +356,7 @@ public class DispatchImpl<T> extends BindingProviderImpl implements Dispatch<T>,
     }
 
     public Future<?> invokeAsync(T obj, AsyncHandler<T> asyncHandler) {
+        
         Response<?> r = invokeAsync(obj);
         AsyncCallbackFuture callback = new AsyncCallbackFuture(r, asyncHandler);
 
