@@ -25,6 +25,7 @@ import java.io.InputStream;
 
 import javax.jms.DeliveryMode;
 
+import org.apache.activemq.ActiveMQConnectionFactory;
 import org.apache.cxf.BusFactory;
 import org.apache.cxf.bus.spring.SpringBusFactory;
 import org.apache.cxf.helpers.IOUtils;
@@ -103,8 +104,8 @@ public class JMSDestinationTest extends AbstractJMSTester {
         BusFactory.setDefaultBus(bus);
         setupServiceInfo("http://cxf.apache.org/jms_conf_test", "/wsdl/others/jms_test_no_addr.wsdl",
                          "HelloWorldQueueBinMsgService", "HelloWorldQueueBinMsgPort");
-        JMSDestination destination = setupJMSDestination(false);
-        JMSConfiguration jmsConfig = destination.getJmsConfig();
+        JMSDestination destination = setupJMSDestination(false);        
+        JMSConfiguration jmsConfig = destination.getJmsConfig();        
         //JmsTemplate jmsTemplate = destination.getJmsTemplate();
         //AbstractMessageListenerContainer jmsListener = destination.getJmsListener();
         assertEquals("Can't get the right ServerConfig's MessageTimeToLive ", 500L, jmsConfig
@@ -117,6 +118,21 @@ public class JMSDestinationTest extends AbstractJMSTester {
         // .getConnectionPassword());
         assertEquals("Can't get the right DurableSubscriberName", "cxf_subscriber", jmsConfig
             .getDurableSubscriptionName());
+        
+        /*setupServiceInfo("http://cxf.apache.org/hello_world_jms", "/wsdl/jms_test.wsdl",
+                         "HelloWorldQueueBinMsgService", "HelloWorldQueueBinMsgPort");
+        destination = setupJMSDestination(false);
+        jmsConfig = destination.getJmsConfig();*/
+        assertEquals("The concurrentConsumer should be set", jmsConfig.getConcurrentConsumers(), 3);
+        assertEquals("The maxConcurrentConsumer should be set", jmsConfig.getMaxConcurrentConsumers(), 5);
+        assertNotNull("The connectionFactory should not be null", jmsConfig.getConnectionFactory());
+        assertTrue("Should get the instance of ActiveMQConnectionFactory", 
+                   jmsConfig.getConnectionFactory() instanceof ActiveMQConnectionFactory);
+        ActiveMQConnectionFactory cf = (ActiveMQConnectionFactory)jmsConfig.getConnectionFactory();
+        assertEquals("The borker URL is wrong", cf.getBrokerURL(), "tcp://localhost:61500");
+        assertEquals("Get a wrong TargetDestination", jmsConfig.getTargetDestination(), "queue:test");
+        assertEquals("Get the wrong pubSubDomain value", jmsConfig.isPubSubDomain(), false);
+        
         BusFactory.setDefaultBus(null);
 
     }
@@ -191,13 +207,18 @@ public class JMSDestinationTest extends AbstractJMSTester {
         destination.shutdown();
     }
 
-    private void setupMessageHeader(Message outMessage) {
+    private void setupMessageHeader(Message outMessage, String correlationId) {
         JMSMessageHeadersType header = new JMSMessageHeadersType();
-        header.setJMSCorrelationID("Destination test");
+        header.setJMSCorrelationID(correlationId);
         header.setJMSDeliveryMode(DeliveryMode.PERSISTENT);
         header.setJMSPriority(1);
         header.setTimeToLive(1000);
         outMessage.put(JMSConstants.JMS_CLIENT_REQUEST_HEADERS, header);
+        outMessage.put(Message.ENCODING, "US-ASCII");
+    }
+    
+    private void setupMessageHeader(Message outMessage) {
+        setupMessageHeader(outMessage, "Destination test");
     }
 
     private void verifyReceivedMessage(Message inMessage) {
@@ -209,13 +230,17 @@ public class JMSDestinationTest extends AbstractJMSTester {
             assertFalse("Read the Destination recieved Message error ", false);
             ex.printStackTrace();
         }
-        String reponse = IOUtils.newStringFromBytes(bytes);
-        assertEquals("The reponse date should be equals", reponse, "HelloWorld");
+        String response = IOUtils.newStringFromBytes(bytes);
+        assertEquals("The response content should be equal", AbstractJMSTester.MESSAGE_CONTENT, response);
     }
 
     private void verifyRequestResponseHeaders(Message inMessage, Message outMessage) {
         JMSMessageHeadersType outHeader = (JMSMessageHeadersType)outMessage
             .get(JMSConstants.JMS_CLIENT_REQUEST_HEADERS);
+        String inEncoding = (String) inMessage.get(Message.ENCODING);
+        String outEncoding = (String) outMessage.get(Message.ENCODING);
+        
+        assertEquals("The message encoding should be equal", inEncoding, outEncoding);
 
         JMSMessageHeadersType inHeader = (JMSMessageHeadersType)inMessage
             .get(JMSConstants.JMS_CLIENT_RESPONSE_HEADERS);
@@ -236,8 +261,13 @@ public class JMSDestinationTest extends AbstractJMSTester {
     }
 
     private void verifyJmsHeaderEquality(JMSMessageHeadersType outHeader, JMSMessageHeadersType inHeader) {
-        assertEquals("The inMessage and outMessage JMS Header's CorrelationID should be equals", outHeader
-            .getJMSCorrelationID(), inHeader.getJMSCorrelationID());
+        if (outHeader.getJMSCorrelationID() != null) {
+            // only check if the correlation id was explicitly set as
+            // otherwise the in header will contain an automatically
+            // generated correlation id
+            assertEquals("The inMessage and outMessage JMS Header's CorrelationID should be equals", outHeader
+                         .getJMSCorrelationID(), inHeader.getJMSCorrelationID());
+        }
         assertEquals("The inMessage and outMessage JMS Header's JMSPriority should be equals", outHeader
             .getJMSPriority(), inHeader.getJMSPriority());
         assertEquals("The inMessage and outMessage JMS Header's JMSDeliveryMode should be equals", outHeader
@@ -255,7 +285,7 @@ public class JMSDestinationTest extends AbstractJMSTester {
         // set up the conduit send to be true
         JMSConduit conduit = setupJMSConduit(true, false);
         final Message outMessage = new MessageImpl();
-        setupMessageHeader(outMessage);
+        setupMessageHeader(outMessage, null);
         final JMSDestination destination = setupJMSDestination(true);
 
         // set up MessageObserver for handling the conduit message
@@ -310,7 +340,7 @@ public class JMSDestinationTest extends AbstractJMSTester {
         // set up the conduit send to be true
         JMSConduit conduit = setupJMSConduit(true, false);
         final Message outMessage = new MessageImpl();
-        setupMessageHeader(outMessage);
+        setupMessageHeader(outMessage, null);
 
         JMSPropertyType excludeProp = new JMSPropertyType();
         excludeProp.setName(customPropertyName);
@@ -336,6 +366,8 @@ public class JMSDestinationTest extends AbstractJMSTester {
                     backConduit = destination.getBackChannel(m, null, null);
                     // wait for the message to be got from the conduit
                     Message replyMessage = new MessageImpl();
+                    // copy the message encoding
+                    replyMessage.put(Message.ENCODING, m.get(Message.ENCODING));
                     sendoutMessage(backConduit, replyMessage, true);
                 } catch (Exception e) {
                     throw new RuntimeException(e);
