@@ -19,12 +19,16 @@
 
 package org.apache.cxf.systest.jaxws;
 
+import java.io.InputStream;
 import java.lang.reflect.UndeclaredThrowableException;
+import java.net.HttpURLConnection;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 
 import javax.xml.namespace.QName;
@@ -32,6 +36,10 @@ import javax.xml.ws.Holder;
 import javax.xml.ws.Service;
 import javax.xml.ws.soap.SOAPBinding;
 import javax.xml.ws.soap.SOAPFaultException;
+import javax.xml.xpath.XPathConstants;
+
+import org.w3c.dom.Document;
+import org.w3c.dom.Node;
 
 import org.apache.cxf.anonymous_complex_type.AnonymousComplexType;
 import org.apache.cxf.anonymous_complex_type.AnonymousComplexTypeService;
@@ -39,7 +47,10 @@ import org.apache.cxf.anonymous_complex_type.RefSplitName;
 import org.apache.cxf.anonymous_complex_type.RefSplitNameResponse;
 import org.apache.cxf.anonymous_complex_type.SplitName;
 import org.apache.cxf.anonymous_complex_type.SplitNameResponse.Names;
+import org.apache.cxf.binding.soap.Soap11;
 import org.apache.cxf.frontend.ClientProxyFactoryBean;
+import org.apache.cxf.helpers.XMLUtils;
+import org.apache.cxf.helpers.XPathUtils;
 import org.apache.cxf.jaxb_element_test.JaxbElementTest;
 import org.apache.cxf.jaxb_element_test.JaxbElementTest_Service;
 import org.apache.cxf.ordered_param_holder.ComplexStruct;
@@ -60,7 +71,7 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
 
     @BeforeClass
     public static void startServers() throws Exception {
-        assertTrue("server did not launch correctly", launchServer(ServerMisc.class, true));
+        assertTrue("server did not launch correctly", launchServer(ServerMisc.class));
     }
     
     @Test
@@ -379,6 +390,7 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
             fail("Expected exception not found");
         } catch (ComplexException ex) {
             assertEquals("Throw user fault -3", ex.getMessage());
+            assertEquals(3, ex.getInts().length);
         }          
         try {
             port.throwException(-3);
@@ -419,11 +431,15 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
     }
 
     private void runRpcLitTest(RpcLitCodeFirstService port) throws Exception {
+       
+        String ret[] = port.convertToString(new int[] {1, 2 , 3});
+        assertEquals(3, ret.length);
+
         List<String> rev = new ArrayList<String>(Arrays.asList(RpcLitCodeFirstServiceImpl.DATA));
-        Collections.reverse(rev);
+        Collections.reverse(rev);        
         
         String s;
-        
+
         String arrayOut[] = port.arrayOutput();
         assertNotNull(arrayOut);
         assertEquals(3, arrayOut.length);
@@ -512,6 +528,7 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
         assertEquals(2, foos2.size());
         assertEquals(2, foos2.get(0).length);
         assertEquals(2, foos2.get(1).length);
+        
     }
       
     @Test
@@ -556,4 +573,44 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
         assertEquals(2, port.operationInSub1(2));
         assertEquals(3, port.operationInSub2(3));
     }
+    
+    
+    
+    @Test
+    public void testAnonymousMinOccursConfig() throws Exception {
+        HttpURLConnection httpConnection = 
+            getHttpConnection(ServerMisc.DOCLIT_CODEFIRST_SETTINGS_URL + "?wsdl");    
+        httpConnection.connect();        
+        
+        assertEquals(200, httpConnection.getResponseCode());
+        assertEquals("OK", httpConnection.getResponseMessage());
+        InputStream in = httpConnection.getInputStream();
+        assertNotNull(in);
+        
+        Document doc = XMLUtils.parse(in);
+        assertNotNull(doc);
+        
+        
+        Map<String, String> ns = new HashMap<String, String>();
+        ns.put("soap", Soap11.SOAP_NAMESPACE);
+        ns.put("tns", "http://cxf.apache.org/systest/jaxws/DocLitWrappedCodeFirstService");
+        ns.put("wsdl", "http://schemas.xmlsoap.org/wsdl/");
+        ns.put("xs", "http://www.w3.org/2001/XMLSchema");
+        
+        
+        XPathUtils xu = new XPathUtils(ns);
+        
+        //make sure the wrapper types are anonymous types
+        Node ct = (Node) xu.getValue("//wsdl:definitions/wsdl:types/xs:schema"
+                                     + "/xs:element[@name='getFooSetResponse']/xs:complexType/xs:sequence",
+                                     doc, XPathConstants.NODE);
+        assertNotNull(ct);
+        
+        //make sure the params are nillable, not minOccurs=0
+        ct = (Node) xu.getValue("//wsdl:definitions/wsdl:types/xs:schema"
+                                + "/xs:element[@name='multiInOut']/xs:complexType/xs:sequence"
+                                + "/xs:element[@nillable='true']",
+                                doc, XPathConstants.NODE);
+        assertNotNull(ct);
+    }
 }
